Attribute VB_Name = "NationalLanguage"
'********************************************************************'
'* Copyright = 5763-XA1 (C) Copyright IBM Corp 1994, 1995.          *'
'*  All rights reserved.                                            *'
'*  Licensed Material - Program property of IBM                     *'
'*  Refer to copyright instructions form number G120-2083.          *'
'********************************************************************'
'********************************************************************'
'*                                                                  *'
'* Module:                                                          *'
'*   CWBNLCNV.H                                                     *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   It contains the declarations for the following API's:          *'
'*                                                                  *'
'*     cwbNL_CCSIDToCodePage                                        *'
'*     cwbNL_CodePageToCCSID                                        *'
'*     cwbNL_Convert                                                *'
'*     cwbNL_ConvertCodePages                                       *'
'*     cwbNL_CreateConverter                                        *'
'*     cwbNL_DeleteConverter                                        *'
'*     cwbNL_GetCodePage                                            *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Link with the CWB.LIB import library.                          *'
'*   This module is to be used in conjunction with CWBNL.DLL.       *'
'*                                                                  *'
'********************************************************************'


'*------------------------------------------------------------------*'
'* TYPEDEFS:                                                        *'
'*------------------------------------------------------------------*'
Public cwbNL_Converter As Integer
Public cwbNL_Conversion_Table As Integer

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_CCSIDToCodePage                                          *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Map CCSIDs to code pages.                                      *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long CCSID - input                                    *'
'*     CCSID to convert to a code page.                             *'
'*                                                                  *'
'*   unsigned long * codePage - output                              *'
'*     The resulting code page.                                     *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_CCSIDToCodePage Lib "CWBNL" (ByVal CCSID As Long, codepage As Long, errorHandle As Integer) As Integer

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_CodePageToCCSID                                          *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Map code pages to CCSIDs.                                      *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long codePage - input                                 *'
'*     Code page to convert to a CCSID.                             *'
'*                                                                  *'
'*   unsigned long * CCSID - output                                 *'
'*     The resulting CCSID.                                         *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_CodePageToCCSID Lib "CWBNL" (ByVal CCSID As Long, codepage As Long, errorHandle As Integer) As Integer

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_Convert                                                  *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Convert strings using a previously opened converter.           *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbNL_Converter theConverter                                   *'
'*     Handle to the previously opened converter.                   *'
'*                                                                  *'
'*   char * sourceBuffer - input                                    *'
'*     Buffer containing the data to convert.                       *'
'*                                                                  *'
'*   char * targetBuffer - output                                   *'
'*     Buffer to contain the converted data.                        *'
'*                                                                  *'
'*   unsigned long sourceLength - input                             *'
'*     Length of the source buffer.                                 *'
'*                                                                  *'
'*   unsigned long targetLength - input                             *'
'*     Length of the target buffer.  If converting from an ASCII    *'
'*     code page that contains DBCS characters, note that the       *'
'*     resulting data could contain shift-out and shift-in bytes.   *'
'*     Therefore the targetBuffer may need to be larger than the    *'
'*     sourceBuffer.                                                *'
'*                                                                  *'
'*   unsigned long * requiredLen - output                           *'
'*     Actual length of the result.  If requiredLen > resultLen,    *'
'*     the return value will be CWB_BUFFER_OVERFLOW.                *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*   CWB_BUFFER_OVERFLOW - Output buffer too small, data truncated. *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_Convert Lib "CWBNL" (ByVal theConverter As Integer, sourceLength As Long, targetLength As Long, ByVal sourceBuffer As String, ByVal targetBuffer As String, numberOfErrors As Long, firstErrorIndex As Long, requiredLen As Long, errorHandle As Integer) As Integer

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_ConvertCodePages                                         *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Convert strings from one code page to another.  This API       *'
'*   combines the three converter APIs for the default conversion.  *'
'*     cwbNL_CreateConverter                                        *'
'*     cwbNL_Convert                                                *'
'*     cwbNL_DeleteConverter                                        *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long sourceCodePage - input                           *'
'*     Code page of the data in the source buffer.                  *'
'*                                                                  *'
'*   unsigned long targetCodePage - input                           *'
'*     Code page to which the data should be converted.             *'
'*                                                                  *'
'*   char * sourceBuffer - input                                    *'
'*     Buffer containing the data to convert.                       *'
'*                                                                  *'
'*   char * targetBuffer - output                                   *'
'*     Buffer to contain the converted data.                        *'
'*                                                                  *'
'*   unsigned long sourceLength - input.                            *'
'*     Length of the source buffer                                  *'
'*                                                                  *'
'*   unsigned long targetLength - input.                            *'
'*     Length of the target buffer                                  *'
'*                                                                  *'
'*   unsigned long * requiredLen - output                           *'
'*     Actual length of the result.  If requiredLen > resultLen,    *'
'*     the return value will be CWB_BUFFER_OVERFLOW.                *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_ConvertCodePages Lib "CWBNL" (ByVal sourceCodePage As Long, ByVal targetCodePage As Long, ByVal sourceLength As Long, ByVal targetLength As Long, ByVal sourceBuffer As String, ByVal targetBuffer As String, numberOfErrors As Long, positionOfFirstError As Long, requiredLen As Long, ByVal errorHandle As Integer) As Integer

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_CreateConverter                                          *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Create a cwbNL_Converter to be used on subsequent calls to     *'
'*   cwbNL_Convert().                                               *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long sourceCodePage - input                           *'
'*     Code page of the source data.                                *'
'*                                                                  *'
'*   unsigned long targetCodePage - input                           *'
'*     Code page to which the data should be converted.             *'
'*                                                                  *'
'*   cwbNL_Converter * theConverter - output                        *'
'*     The newly created converter.                                 *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'*   unsigned long shiftInShiftOutStatus - input                    *'
'*     Indicates whether the shift-in and shift-out bytes are part  *'
'*     of the input or output data.                                 *'
'*     0 - False, no shift-in and shift-out bytes are part          *'
'*         of the data string.                                      *'
'*     1 - True, shift-in and shift-out characters are part of the  *'
'*         data string.                                             *'
'*                                                                  *'
'*   unsigned long padLength - input                                *'
'*     Length of pad characters.                                    *'
'*     0 - No pad characters for this conversion request            *'
'*     1 - 1 byte of pad character. This is valid for only if       *'
'*         the target code page is either SBCS or DBCS code page    *'
'*     2 - 2 bytes of pad characters. This is valid only if the     *'
'*         code page is not a single-byte code page.                *'
'*                                                                  *'
'*   char * pad - input                                             *'
'*     The character or characters for padding.                     *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*   Instead of calling cwbNL_ConvertCodePages multiple times with  *'
'*   the same code pages:                                           *'
'*                                                                  *'
'*     cwbNL_ConvertCodePages(850, 500, ...);                       *'
'*     cwbNL_ConvertCodePages(850, 500, ...);                       *'
'*     cwbNL_ConvertCodePages(850, 500, ...);                       *'
'*                                                                  *'
'*   It is more efficient to create a converter and use it          *'
'*   multiple times:                                                *'
'*                                                                  *'
'*     cwbNL_CreateConverter(850, 500, &conv, ...);                 *'
'*     cwbNL_Convert(conv, ...);                                    *'
'*     cwbNL_Convert(conv, ...);                                    *'
'*     cwbNL_Convert(conv, ...);                                    *'
'*     cwbNL_DeleteConverter(conv, ...);                            *'
'*                                                                  *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_CreateConverter Lib "CWBNL" (ByVal sourceCodePage As Long, ByVal targetCodePage As Long, ByVal theConverter As Long, ByVal errorHandle As Integer, ByVal shiftInShiftOutStatus As Long, ByVal padLength As Long, ByVal pad As String) As String
                 
'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_DeleteConverter                                          *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Delete a cwbNL_Converter.                                      *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   cwbNL_Converter theConverter - input                           *'
'*     A previously created converter.                              *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_DeleteConverter Lib "CWBNL" (ByVal theConverter As Integer, ByVal errorHandle As Integer) As Integer

'********************************************************************'
'*                                                                  *'
'* API:                                                             *'
'*   cwbNL_GetCodePage                                              *'
'*                                                                  *'
'* Purpose:                                                         *'
'*   Get the code page of the current process.                      *'
'*                                                                  *'
'* Parameters:                                                      *'
'*   unsigned long * codePage - output                              *'
'*     Code page of the current process.                            *'
'*                                                                  *'
'*   cwbSV_ErrHandle errorHandle - output                           *'
'*     Handle to an error object.                                   *'
'*     Any returned messages will be written to this object.        *'
'*     It is created with the cwbSV_CreateErrHandle API.            *'
'*     The messages may be retrieved with the cwbSV_GetErrText API. *'
'*     If the parameter is set to zero, no messages will be         *'
'*     retrievable.                                                 *'
'*                                                                  *'
'* Return Codes:                                                    *'
'*   The following list shows common return values.                 *'
'*                                                                  *'
'*   CWB_OK - Successful completion.                                *'
'*   CWB_INVALID_HANDLE - Invalid handle.                           *'
'*   CWB_INVALID_POINTER - NULL passed on output parameter.         *'
'*   CWB_NOT_ENOUGH_MEMORY - Insufficient memory.                   *'
'*                                                                  *'
'* Usage Notes:                                                     *'
'*                                                                  *'
'********************************************************************'
Declare Function cwbNL_GetCodePage Lib "CWBNL" (codepage As Long, ByVal errorHandle As Integer) As Integer


